@@ -1,5 +1,5 @@
 package DateTime::TimeZone::Local::Win32;
-$DateTime::TimeZone::Local::Win32::VERSION = '1.96';
+$DateTime::TimeZone::Local::Win32::VERSION = '1.97';
 use 5.006;
 
 use strict;
@@ -123,6 +123,7 @@ sub EnvVars { return 'TZ' }
         'Line Islands Standard Time'      => 'Pacific/Kiritimati',
         'Lord Howe Standard Time'         => 'Australia/Lord_Howe',
         'Magadan Standard Time'           => 'Asia/Magadan',
+        'Magallanes Standard Time'        => 'America/Punta_Arenas',
         'Marquesas Standard Time'         => 'Pacific/Marquesas',
         'Mauritius Standard Time'         => 'Indian/Mauritius',
         'Mexico'                          => 'America/Mexico_City',
@@ -316,7 +317,7 @@ DateTime::TimeZone::Local::Win32 - Determine the local system's time zone on Win
 
 =head1 VERSION
 
-version 1.96
+version 1.97
 
 =head1 SYNOPSIS
 
@@ -383,7 +384,7 @@ of "SOFTWARE/Microsoft/Windows/CurrentVersion/Time Zones/"
 
 =item *
 
-David Pinkowitz <david_pinkowitz@bmc.com>
+David Pinkowitz <dapink@cpan.org>
 
 =item *
 
@@ -394,7 +395,7 @@ Dave Rolsky <autarch@urth.org>
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (C) 2007-2014 Dave Rolsky <autarch@urth.org>
-Copyright (C) 2014-2017 by David Pinkowitz <david_pinkowitz@bmc.com>
+Copyright (C) 2014-2017 by David Pinkowitz <dapink@cpan.org>
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
